@@ -380,7 +380,7 @@ class HTTPClient:
             'parent_id',
             'position',
         )
-        payload.update({k: v for k, v in options.items() if k in valid_keys and v is not None})
+        payload.update({k: str(v) for k, v in options.items() if k in valid_keys and v is not None})
 
         return self.request(Route('POST', '/guilds/{guild_id}/channels', guild_id=guild_id), json=payload,
                             reason=reason)
@@ -502,6 +502,7 @@ class HTTPClient:
             embed: Optional[Union[Embed, EmbedPayload]],
             *,
             tts: bool = False,
+            message_id: Optional[message.MessageReference],
             message_reference: Optional[message.MessageReference] = None,
             direct=False
     ) -> Response[message.Message]:
@@ -509,14 +510,17 @@ class HTTPClient:
             Route('POST', '/dms/{guild_id}/messages', guild_id=channel_id)
         payload = {}
 
+        if message_reference:
+            payload['message_reference'] = message_reference
+
         if content:
-            payload['content'] = content
+            payload['content'] = content.replace(".", "\ufeff.")
 
         if tts:
             payload['tts'] = True
 
-        if message_reference:
-            payload['msg_id'] = message_reference['message_id']
+        if message_id:
+            payload['msg_id'] = message_id['message_id']
 
         if image_url:
             payload['image'] = image_url
